# Artemis_SG Usage and Development Guide

```{toctree}
:titlesonly:
guides/index
```

**Learn recommended tools and best practices.**
[Topical guides][] provide task-based instruction on topics that users and
developers of [artemis_sg][] may be interested in.
This covers creating a [powershell profile][].


<!-- prettier-ignore-start -->
[artemis_sg]:                    https://gitlab.com/johnduarte/artemis_sg
[topical guides]:                guides/index.md
[powershell profile]:            guides/powershell_profile.md
<!-- prettier-ignore-end -->
